#!/bin/bash
#

inv=`tput smso`
nor=`tput rmso`
UPLOAD=/backups/upload
PATCHBASE=/backups/patch
LOCK=/var/lock/subsys

heading() {
 clear
 echo "${inv} Swivel Maintenance (c) 2008${nor}
            ${inv}$PINSAFE_TYPE${nor}"
 echo
 echo $1
 echo
}

s_heading() {
 clear
 echo "${inv} Swivel Maintenance (c) 2008${nor}
            ${inv}$PINSAFE_TYPE${nor}"
 echo
}

yorn() {
 echo
 echo -n "Are you sure? (Yes/No): "
 read yn
 check_ans $1 $yn
}

check_ans() {
 if test ! $2; then
  $1; fi
 if test ! $2 = "Yes" && test ! $2 = "yes" && test ! $2 = "y" && test ! $2 = "Y" ; then
  $1; fi
}

get_patch_ver() {
 PATCH_VER=`cat $PATCHBASE/patch_ver`
 PATCH_VER_ORIG=`grep APPLIANCE_PATCH_VER /etc/pinsafe.conf|cut -d\= -f2`
 patch_ver_new=`echo $PATCH_VER|cut -d\. -f3`
 patch_ver_existing=`grep APPLIANCE_PATCH_VER /etc/pinsafe.conf|cut -d\. -f3`
}

update_patch_ver() {
 sed -i "s/APPLIANCE_PATCH_VER=$PATCH_VER_ORIG/APPLIANCE_PATCH_VER=$PATCH_VER/g" /etc/pinsafe.conf
}

test_patch_ver(){
 p1=`expr $patch_ver_existing + 1`

 if test $patch_ver_new -le $patch_ver_existing; then
  echo "This patch has already been applied."
  echo
  echo "   Current patch level of appliance: $PATCH_VER_ORIG"
  echo "   Patch version: $PATCH_VER"
  echo
  read -p "Press Return to exit"
  exit; fi

 if test $p1 -gt $patch_ver_new; then
  echo "The applaince patch version is newer than the patch you are trying to apply."
  echo
  echo "   Current patch level of appliance: $PATCH_VER_ORIG"
  echo "   Patch version: $PATCH_VER"
  echo
  read -p "Press Return to exit"
  exit; fi

 if test $p1 -lt $patch_ver_new; then
  echo "Please apply the previous patches before applying this patch. Existing patch"
  echo "level is too low:"
  echo
  echo "   Current patch level of appliance: $PATCH_VER_ORIG"
  echo "   Patch version: $PATCH_VER"
  echo
  read -p "Press Return to exit"
  exit; fi
}

# Create update routine. Use Standard calls above.

commands() {
 heading "Upgrading Swivel"
 install_swivel
}

check_running() {
 if test "`ps -eaf|grep $2|egrep -v "UID|grep|mysqld_safe|alert.d" 2>/dev/null`"; then
  if test ! -f $LOCK/$1; then
   touch $LOCK/$1; fi
 else
  if test -f $LOCK/$1; then
   rm -f $LOCK/$1; fi
 fi

 if test -f $LOCK/$1; then
  value="Running"
 else
  value="Stopped"
 fi
}

show_dots() {
 i=0
 while test $i -lt $1; do
  echo -n "."
  sleep 1 
  ((i = i + 1))
 done
}

service_sands_tomcat() {
 nohup service tomcat5 $1 > /dev/null 2>&1 &
 echo -n "Tomcat: $1"
 show_dots 4
}

service_sands() {
 service $1 $2
}

install_swivel() {
 pinsafe=${1-pinsafe}
 pinsafedir=$TOMCAT_PATH/webapps/$pinsafe/WEB-INF
 swivelhome=${SWIVEL_HOME-"/home/swivel"}

 check_running tomcat5 tomcat
 if test $value = "Running"; then
  echo "Stopping Tomcat and Swivel service"
  service_sands tomcat5 stop
 fi
 
 echo "Creating new Swivel configuration dir."
 mkdir -p $swivelhome/.swivel
 chown -R swivel:swivel $swivelhome/.swivel
 
 echo "Creating backups of original configurations"
 cp -rp $pinsafedir/conf $swivelhome/.swivel/.
 cp -rp $pinsafedir/data $swivelhome/.swivel/.
 cp -rp $pinsafedir/db $swivelhome/.swivel/.
 cp -rp $pinsafedir/logs $swivelhome/.swivel/.
 if test -d $pinsafedir/active-mq; then
  cp -rp $pinsafedir/active-mq $swivelhome/.swivel/.
 fi

 if test -d $pinsafedir/reports; then
  cp -rp $pinsafedir/reports $swivelhome/.swivel/.
 fi

 echo "Creating backups of original configurations"
 cp -rp $TOMCAT_PATH/webapps/pinsafe /tmp

 echo "Starting Tomcat and Swivel service"
 service_sands_tomcat start

 echo; echo "Deploying new Swivel software"
 cp pinsafe.war $TOMCAT_PATH/webapps 

 echo "Upgrade complete"
}

commands
echo; read -p "Press Return to continue" yn
